###################################################
### chunk number 1: startup
###################################################
options(SweaveHooks=list(fig=function() par(mar = c (4.1, 4.1, 1, .6), family="serif")))
options ("width" = 100)


###################################################
### chunk number 2: init
###################################################
library (hyperSpec)


###################################################
### chunk number 3: help1 eval=FALSE
###################################################
## ? plotmath


###################################################
### chunk number 4: help2 eval=FALSE
###################################################
## demo (plotmath)


###################################################
### chunk number 5: print
###################################################
chondro
summary (chondro)


###################################################
### chunk number 6: nwl
###################################################
nrow (chondro)
nwl (chondro)
ncol (chondro)
dim (chondro)


###################################################
### chunk number 7: names
###################################################
colnames (chondro)


###################################################
### chunk number 8: scan.txt.Renishaw
###################################################
paracetamol <- scan.txt.Renishaw ("paracetamol.txt", "spc")
paracetamol


###################################################
### chunk number 9: cbind
###################################################
cbind (chondro [, , 600 ~ 800], chondro [, , 1600 ~ 1800])
rbind (chondro [, , 600 ~ 800], chondro [, , 600 ~ 800])


###################################################
### chunk number 10: delspc
###################################################
flu [1 : 3]
flu [-3]
chondro  [chondro$y > 10]


###################################################
### chunk number 11: data
###################################################
colnames (chondro)
chondro [[1 : 3, 1]]
chondro [[1 : 3, -3]]
chondro [[1 : 3, "x"]]
chondro [[1 : 3, c (TRUE, FALSE, FALSE)]]


###################################################
### chunk number 12: data2
###################################################
flu$c


###################################################
### chunk number 13: data3
###################################################
flu$n <- list (1 : 6, label = "sample no.")


###################################################
### chunk number 14: wl2ivec
###################################################
wl2i (flu, 405 : 410)


###################################################
### chunk number 15: wl2ivec2
###################################################
wl2i (flu, 405 ~ 410)


###################################################
### chunk number 16: wl2ivec3
###################################################
wl2i (chondro, 1000 : 1010)


###################################################
### chunk number 17: wl2ivec4
###################################################
wl2i (chondro, 1000 ~ 1010)


###################################################
### chunk number 18: wl2i.minmax
###################################################
wl2i (flu, min ~ 410)


###################################################
### chunk number 19: wl2i.im
###################################################
wl2i (flu, 450 - 2i ~ 450 + 2i)
wl2i (flu, max - 2i ~ max)


###################################################
### chunk number 20: wl2i.list
###################################################
wl2i (flu, 450 - 2i ~ 450 + 2i)
wl2i (flu, c (min ~ 406.5, max - 2i ~ max))


###################################################
### chunk number 21: plotspc
###################################################
plotspc (flu)


###################################################
### chunk number 22: plotspcmeansd
###################################################
plot (chondro, "spcmeansd")


###################################################
### chunk number 23: plotc
###################################################
plotc (flu)


###################################################
### chunk number 24: plotmap
###################################################
print (plotmap (chondro))


###################################################
### chunk number 25: ms
###################################################
fake.mass.spec <- new ("hyperSpec", spc = matrix (100*runif (25), nrow = 1),
   wavelength = 1 : 25 + 28,
   label = list (spc = expression (e^"-" / s), .wavelength = expression (m / z)))
plot (fake.mass.spec, lines.args = list (type = "h"))


###################################################
### chunk number 26: plotspcadd
###################################################
plot (paracetamol, wl.range = c (300 ~ 1800, 2800 ~ max), xoffset = 850, wl.reverse = TRUE, col = "blue")


###################################################
### chunk number 27: cut.wl
###################################################
flu [,, min ~ 408.5]
flu [[,, c (min ~ min + 2i, max - 2i ~ max)]]


###################################################
### chunk number 28: fig-loess
###################################################
plot (paracetamol, wl.range = c (300 ~ 1800, 2800 ~ max), xoffset = 850)
p <- spc.loess (paracetamol, c(seq (300, 1800, 2), seq (2850, 3150, 2)))
plot (p, wl.range = c (300 ~ 1800, 2800 ~ max), xoffset = 850, col = "red", add = TRUE)


###################################################
### chunk number 29: fig-loess-kl
###################################################
plot (paracetamol [, , 1600 ~ 1670])
plot (p [, , 1600 ~ 1670], col = "red", add = TRUE)


###################################################
### chunk number 30: ofs
###################################################
offsets <- apply (chondro, 1, min)
chondro.offset.corrected <- sweep (chondro, 1, offsets, "-")


###################################################
### chunk number 31: bl
###################################################
bl <- spc.fit.poly.below (chondro)
chondro <- chondro - bl


###################################################
### chunk number 32: norm
###################################################
factors <- 1 / apply (chondro, 1, mean)
chondro <- sweep (chondro, 1, factors, "*")


###################################################
### chunk number 33: centre-flu
###################################################
flu.centered <- sweep (flu, 2, apply (flu, 2, mean), "-")


###################################################
### chunk number 34: fig-centre-flu
###################################################
plot (flu.centered)


###################################################
### chunk number 35: perc
###################################################
chondro <- sweep (chondro, 2, apply (chondro, 2, quantile, 0.05), "-")


###################################################
### chunk number 36: fig-centre-ch
###################################################
plot (chondro, "spcprctl5")


###################################################
### chunk number 37: msc eval=FALSE
###################################################
## library (pls)
## chondro.msc <- chondro
## chondro.msc [[]] <- msc (chondro [[]])


###################################################
### chunk number 38: label eval=FALSE
###################################################
## labels (absorbance.spectra)$spc <- "A"


###################################################
### chunk number 39: pca
###################################################
pca <- prcomp (~ spc, data = chondro$., centre = FALSE)


###################################################
### chunk number 40: decomp
###################################################
scores <- decomposition (chondro, pca$x, label.wavelength = "PC", label.spc = "score / a.u.")
loadings <- decomposition (chondro, t(pca$rotation), scores = FALSE, label.spc = "loading I / a.u.")


###################################################
### chunk number 41: pca-load
###################################################
plot (loadings [1:3], stacked = TRUE)


###################################################
### chunk number 42: pca-score
###################################################
print (plotmap (scores [,,2]))


###################################################
### chunk number 43: hca
###################################################
dist <- pearson.dist (chondro [[]])
dendrogram <- hclust (dist, method = "ward")


###################################################
### chunk number 44: dend
###################################################
plot (dendrogram)


###################################################
### chunk number 45: dendcut
###################################################
clusters <- cutree (dendrogram, k = 3)


###################################################
### chunk number 46: clustmap
###################################################
plotmap (chondro, z = as.factor (clusters), do.print = TRUE)


###################################################
### chunk number 47: clustmean
###################################################
means <- aggregate (chondro, by = clusters, mean_pm_sd)
means
plot (means, col = matlab.palette (3), stacked = ".aggregate", fill = ".aggregate")


###################################################
### chunk number 48: split
###################################################
clusters <- split (chondro, clusters)
clusters


###################################################
### chunk number 49: cleanup
###################################################
rm (list = ls () )


